# ScrapeWebdriver
Class based on selenium webdriver.Firefox with methods for scraping.

Versions:
0.2 - added methods for changing proxy without closing driver and for getting soup with BeautifulSoup.
0.3 - added extension for proxy with authentication, adblock, webdriver-manager for automatically find driver


### Installation
`pip install scrapy_webdriver`
